/*
 * Copyright (C) 2014 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import "../common/ClockUtils.js" as Utils

Column {
    id: listAlarm

    // Property to determine the size of the alarms listview height
    property int maxItemsVisible

    // Property to store the model of the saved alarm list
    property alias model: listSavedAlarm.model

    // Property to help with the dynamic positioning of the alarm list
    property alias headerHeight: savedAlarmHeader.height
    property alias dividerHeight: divider.height

    visible: listSavedAlarm.count !== 0

    ListItem.ThinDivider { id: divider }

    ListItem.Header {
        id: savedAlarmHeader
        Label {
            text: i18n.tr("Alarms")
            anchors { verticalCenter: parent.verticalCenter; left: parent.left; leftMargin: units.gu(2) }
            color: Theme.palette.normal.baseText
            fontSize: "medium"
        }
    }

    ListView {
        id: listSavedAlarm
        objectName: "listSavedAlarm"
        
        clip: true
        anchors { left: parent.left; right: parent.right }
        height: listAlarm.maxItemsVisible * units.gu(6)
        currentIndex: -1
        
        delegate: ListItem.Base {
            objectName: "alarm" + index
            Label {
                id: alarmTime
                objectName: "listAlarmTime" + index
                fontSize: "large";
                text: Utils.convertTime(date.getHours(), date.getMinutes(), 0, appSetting.contents.timeFormat)
                anchors { verticalCenter: parent.verticalCenter; right: alarmStatus.left; rightMargin: units.gu(2) }
                color: Theme.palette.normal.baseText
            }
            
            Label {
                id: alarmLabel
                objectName: "listAlarmLabel" + index
                fontSize: "large";
                text: message
                elide: Text.ElideRight
                anchors {
                    left: parent.left;
                    right: alarmTime.left
                    rightMargin: units.gu(2)
                    leftMargin: units.gu(1);
                    verticalCenter: alarmTime.top;
                    verticalCenterOffset: units.gu(0.4)
                }
                color: Theme.palette.normal.baseText
            }
            
            Label {
                id: alarmSubtitle
                objectName: "listAlarmSubtitle" + index
                fontSize: "small";
                text: format_day_string(daysOfWeek, type)
                anchors { left: alarmLabel.left; top: alarmLabel.bottom }
                color: Theme.palette.normal.backgroundText
            }
            
            Switch {
                id: alarmStatus
                objectName: "listAlarmStatus" + index
                checked: model.enabled
                anchors { right: parent.right; verticalCenter: alarmTime.verticalCenter }
                onClicked: {
                    var alarm = alarmModel.get(index);
                    alarm.enabled = checked
                    alarm.save();
                }
            }
            
            selected: listSavedAlarm.currentIndex == index
            removable: true
            confirmRemoval: true
            
            onItemRemoved: {
                var alarm = alarmModel.get(index)
                alarm.cancel()
            }
            
            onClicked: pagestack.push(Qt.resolvedUrl("AddAlarmPage.qml"), {"isNewAlarm": false, "alarmIndex": index})
        }
    }
}
