/*
 * Copyright (C) 2014 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import "../common/ClockUtils.js" as Utils

Column {
    id: savedWorldClock

    // Property to point to the World Clock List model
    property alias model: listWorldClocks.model

    // Properties to help with the positioning the world list column
    property alias dividerHeight: divider.height
    property alias headerHeight: worldLocationHeader.height

    // Property to check if there are any saved world clocks
    property bool checkWorldCityCount: listWorldClocks.count !== 0

    // Property to determine the size of the world clocks listview height
    property int maxItemsVisible

    visible: checkWorldCityCount

    ListItem.ThinDivider {
        id: divider
    }
    
    ListItem.Header {
        id: worldLocationHeader
        Label {
            text: i18n.tr("World")
            anchors { verticalCenter: parent.verticalCenter; left: parent.left; leftMargin: units.gu(2) }
            color: Theme.palette.normal.baseText
            fontSize: "medium"
        }
    }
    
    ListView {
        id: listWorldClocks
        objectName: "listWorldClocks"
        
        clip: true
        anchors { left: parent.left; right: parent.right }
        height: maxItemsVisible * units.gu(6) // height is defined to show 5 items by default in phone layout
        currentIndex: -1
        
        delegate: ListItem.Standard {
            objectName: "savedworldcity" + index
            Label {
                id: worldCityName
                text: model.contents.city
                objectName: "city_name"
                elide: Text.ElideRight
                anchors { verticalCenter: parent.verticalCenter; left: parent.left; right: worldCityTime.left; margins: units.gu(3) }
                color: Theme.palette.normal.baseText
                fontSize: "large"
            }
            
            Label {
                id: worldCityTime
                text: appSetting.contents.timeFormat === "12-hour" ? Qt.formatTime(new Date(currentUTCTime + (model.contents.rawOffSet * 60000)), "h:mm AP") : Qt.formatTime(new Date(currentUTCTime + (model.contents.rawOffSet * 60000)), "hh:mm")
                anchors { verticalCenter: parent.verticalCenter; right: parent.right; rightMargin: units.gu(2) }
                color: Theme.palette.normal.baseText
                fontSize: "large"
            }
            
            selected: listWorldClocks.currentIndex == index
            removable: true
            confirmRemoval: true
            
            onItemRemoved: {
                // NOTE: This causes the document to be deleted twice resulting in an error.
                // The bug has been reported at https://bugs.launchpad.net/ubuntu-ui-toolkit/+bug/1276118
                Utils.log("Deleting world location: " + model.contents.city)
                db.putDoc("", model.docId)
            }
        }
    }
}
