# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013, 2014 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Renato Araujo Oliveira Filho <renato@canonical.com>
#              Nekhelesh Ramananthan <krnekhelesh@gmail.com>

"""
Tests for the Clock App, main window.
"""

from __future__ import absolute_import

from testtools.matchers import Equals
from autopilot.matchers import Eventually

from ubuntu_clock_app.tests import ClockAppTestCase


class TestClock(ClockAppTestCase):
    """Test the clock page features."""

    def setUp(self):
        """This is needed to wait for the application to start.

        In the testfarm, the application may take some time to show up.

        """

        super(TestClock, self).setUp()
        self.assertThat(
            self.main_view.visible, Eventually(Equals(True)))

        self.page = self.main_view.open_clock()

    def test_enable_seconds_settings_must_show_second_hand(self):
        """Test if enabling the show seconds settings works as expected

        This test enables the show seconds settings option and checks if the
        clock seconds hand is visible

        """
        self.page.show_seconds_hand()
        self.assertThat(
            self.page.is_seconds_hand_visible,
            Eventually(Equals(True)))

    def test_enable_12_hour_settings_must_show_time_in_12_hour(self):
        """Test if setting the 12-hour time format settings option works

        This test sets the time format to 12-hour time format and checks if the
        time is shown in the 12-hour format

        """
        self.page.enable_12_hour_time_format()
        self.assertThat(
            self.page.is_12_hour_time,
            Eventually(Equals(True)))

    def test_enable_24_hour_settings_must_show_time_in_24_hour(self):
        """Test if setting the 12-hour time format settings option works

        This test sets the time format to 24-hour time format and checks if the
        time is shown in the 24-hour format

        """
        self.page.enable_24_hour_time_format()
        self.assertThat(
            self.page.is_12_hour_time,
            Eventually(Equals(False)))

    def test_add_city_button_must_add_world_city(self):
        """Test if adding a listed world city works"""
        old_city_count = self.page.get_num_of_saved_cities()
        self.page.add_world_city(index=0)
        # Confirm that the city has been added
        self.assertThat(
            self.page.get_num_of_saved_cities,
            Eventually(Equals(old_city_count + 1)))

    def test_delete_world_city_must_delete_saved_world_city_list(self):
        """Test to check if deleting a saved local world city works"""
        self.page.add_world_city(index=0)
        old_city_count = self.page.get_num_of_saved_cities()
        self.page.delete_world_city(index=0)
        # Confirm that the city has been deleted
        self.assertThat(
            self.page.get_num_of_saved_cities,
            Eventually(Equals(old_city_count - 1)))
