# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013, 2014 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>

"""Tests for the Clock App - Stopwatch"""

from __future__ import absolute_import

import time
from testtools.matchers import Equals, NotEquals
from autopilot.matchers import Eventually

from ubuntu_clock_app.tests import ClockAppTestCase


class TestStopwatch(ClockAppTestCase):
    """Tests the stopwatch page features"""

    def setUp(self):
        """ This is needed to wait for the application to start.

        In the testfarm, the application may take some time to show up.

        """
        super(TestStopwatch, self).setUp()
        self.assertThat(
            self.main_view.visible, Eventually(Equals(True)))

        self.page = self.main_view.open_stopwatch()

    def test_click_clock_center_must_start_stopwatch(self):
        """Test if start button starts the stopwatch"""
        stopwatch_time = self.page.get_stopwatch_time()
        self.page.start_stopwatch()
        # Check the stopwatch started running
        self.assertThat(stopwatch_time, Eventually(NotEquals('00:00.0')))

    def test_click_clock_center_with_stopwatch_started_must_stop_it(self):
        """Test if stop button stops the stopwatch"""
        self.page.start_stopwatch()
        self.page.stop_stopwatch()
        # Check that the stopwatch has stopped
        stopwatch_time = self.page.get_stopwatch_time()
        time.sleep(1)
        self.assertThat(
            stopwatch_time,
            Equals(self.page.get_stopwatch_time()))

    def test_restart_button_must_restart_stopwatch_time(self):
        """Test if reset button resets the stopwatch time"""
        self.page.start_stopwatch()
        stopwatch_time = self.page.get_stopwatch_time()
        self.page.reset_stopwatch()
        # Check that the stopwatch has been reset
        self.assertThat(stopwatch_time, Eventually(Equals('00:00.0')))

    def test_lap_button_must_create_stopwatch_lap(self):
        """Test if lap button creates a stopwatch lap"""
        self.page.start_stopwatch()
        num_of_laps_old = self.page.get_num_of_laps()
        self.page.create_lap()
        # Confirm that the lap is created
        self.assertThat(
            self.page.get_num_of_laps,
            Eventually(Equals(num_of_laps_old + 1)))

    def test_delete_lap_must_delete_from_stopwatch_lap_list(self):
        """Test to delete a lap and check if it has been removed properly"""
        self.page.start_stopwatch()
        self.page.create_lap()
        num_of_laps_old = self.page.get_num_of_laps()
        self.page.delete_lap(index=0)
        # Check that the stopwatch lap has been deleted
        self.assertThat(
            self.page.get_num_of_laps,
            Eventually(Equals(num_of_laps_old - 1)))
