# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013, 2014 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Riccardo Padovani <rpadovani@ubuntu-it.org>
#              Nekhelesh Ramananthan <krnekhelesh@gmail.com>

"""Tests for the Clock App - Timer"""

from __future__ import absolute_import

from testtools.matchers import Equals, NotEquals
from autopilot.matchers import Eventually

from ubuntu_clock_app.tests import ClockAppTestCase
import logging

logger = logging.getLogger(__name__)


class TestTimer(ClockAppTestCase):
    """Tests the timer page features"""

    def setUp(self):
        """This is needed to wait for the application to start.

        In the testfarm, the application may take some time to show up.

        """
        super(TestTimer, self).setUp()
        self.assertThat(
            self.main_view.visible, Eventually(Equals(True)))

        self.page = self.main_view.open_timer()

    def test_add_timer_must_add_timer_to_presets_lists(self):
        """Test to check if button to add a preset working."""
        num_of_presets_old = self.page.get_num_of_presets()
        self.page.add_timer('test', set_time=True)

        # check that the timer preset has been added.
        self.assertThat(
            self.page.get_num_of_presets,
            Eventually(Equals(num_of_presets_old + 1)))

        last_preset_name, _ = self.page.get_presets()[0]
        self.assertEqual('test', last_preset_name)

    def test_run_preset_must_run_timer(self):
        """Tests if a preset can run."""
        # FIXME: Instead of always running the first preset, run the preset
        # which was passed as argument. To do this in a nice way, we should use
        # the QQuickListView but it has a bug that makes it fail in this case:
        # http://pad.lv/1275060 --elopio - 2014-01-31
        timer_index = 0
        _, initial_time = self.page.get_presets()[timer_index]
        self.page.run_preset_timer(index=timer_index)

        self.assertThat(
            self.page.get_current_time, Eventually(NotEquals(initial_time)))

    def test_edit_preset_must_update_preset(self):
        """Test if a preset can be edited and updated with new values"""
        # FIXME: Instead of always editing the first preset, edit the preset
        # passed as an argument. To do this in a nice way, we should use the
        # QQuickListView but it has a bug that makes it fail in this case:
        # http://pad.lv/1275060 --elopio - 2014-01-31
        timer_index = 0
        initial_name, _ = self.page.get_presets()[timer_index]
        edited_name = initial_name + 'Edit'
        self.page.edit_preset_timer(edited_name, timer_index)
        new_preset_name, _ = self.page.get_presets()[timer_index]

        # check that the edited preset has the new preset name and not the
        # original preset name
        self.assertEqual(edited_name, new_preset_name)

    def test_delete_preset_must_remove_from_presets_list(self):
        """Test if the swipe of a preset deletes it."""
        # FIXME: Instead of always deleting the first preset, delete the preset
        # passed as an argument. To do this in a nice way, we should use the
        # QQuickListView but it has a bug that makes it fail in this case:
        # http://pad.lv/1275060 --elopio - 2014-01-31
        num_of_presets_old = self.page.get_num_of_presets()
        self.page.delete_preset_timer(index=0)

        # Check that the timer preset has been deleted
        self.assertThat(
            self.page.get_num_of_presets,
            Eventually(Equals(num_of_presets_old - 1)))
